Installation — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Installation

The project was developed using Python 3.10. It’s not recommended to use oldered versions of Python as dataclass and type hints are used. To install packages required to run the project you can use either pip or conda. 1. Install packages using pip: $ pip install -r requirements.txt 2. Install packages using conda: $ conda env create -f environment.yml -> $ conda activate extractor